==> androidnotify-0.0.4.tar.gz: android/src/main/java/cachet/plugins/notifications/NotificationListener.java <==
package cachet.plugins.notifications;

import android.app.Notification;
import android.content.Intent;
import android.service.notification.NotificationListenerService;
import android.service.notification.StatusBarNotification;
import android.util.Log;

/**
 * Notification listening service. Intercepts notifications if permission is given to do so.
 */
public class NotificationListener extends NotificationListenerService {

    public static String NOTIFICATION_INTENT = "notification_event";
    public static String NOTIFICATION_PACKAGE_NAME = "package_name";
    public static String NOTIFICATION_TITLE="title";
    public static String NOTIFICATION_TEXT="text";
    private String TAG = NotificationListener.class.getSimpleName();
    @Override
    public void onCreate() {
        super.onCreate();
    }
    @Override
    public void onListenerConnected() {
        //当连接成功时调用，一般在开启监听后会回调一次该方法
        Log.d(TAG,"onListenerConnected");
    }

    @Override
    public void onNotificationPosted(StatusBarNotification sbn) {
        Log.d(TAG,"通知测试,"+sbn.toString());
        String packageName = sbn.getPackageName();
        String text=sbn.getNotification().extras.getString(Notification.EXTRA_TEXT);
        String title=sbn.getNotification().extras.getString(Notification.EXTRA_TITLE);
        Intent intent = new  Intent(NOTIFICATION_INTENT);
        intent.putExtra(NOTIFICATION_PACKAGE_NAME, packageName);
        intent.putExtra(NOTIFICATION_TITLE, title);
        intent.putExtra(NOTIFICATION_TEXT, text);
        sendBroadcast(intent);
    }
}

==> androidnotify-0.0.5.tar.gz: android/src/main/java/cachet/plugins/notifications/NotificationListener.java <==
package cachet.plugins.notifications;

import android.app.Notification;
import android.content.Intent;
import android.service.notification.NotificationListenerService;
import android.service.notification.StatusBarNotification;
import android.util.Log;

/**
 * Notification listening service. Intercepts notifications if permission is given to do so.
 */
public class NotificationListener extends NotificationListenerService {

    public static String NOTIFICATION_INTENT = "notification_event";
    public static String NOTIFICATION_PACKAGE_NAME = "package_name";
    public static String NOTIFICATION_TITLE="title";
    public static String NOTIFICATION_TEXT="text";
    private String TAG = NotificationListener.class.getSimpleName();
    @Override
    public void onCreate() {
        super.onCreate();
    }
    @Override
    public void onListenerConnected() {
        //当连接成功时调用，一般在开启监听后会回调一次该方法
//        Log.d(TAG,"onListenerConnected");
    }

    @Override
    public void onNotificationPosted(StatusBarNotification sbn) {
        String packageName = sbn.getPackageName();
        String text=sbn.getNotification().extras.getString(Notification.EXTRA_TEXT);
        String title=sbn.getNotification().extras.getString(Notification.EXTRA_TITLE);
        Intent intent = new  Intent(NOTIFICATION_INTENT);
        intent.putExtra(NOTIFICATION_PACKAGE_NAME, packageName);
        intent.putExtra(NOTIFICATION_TITLE, title);
        intent.putExtra(NOTIFICATION_TEXT, text);
        sendBroadcast(intent);
    }
}
